# this file is @generated
import typing as t

from .common import BaseModel


class StreamPortalAccessIn(BaseModel):
    expiry: t.Optional[int] = None
    """How long the token will be valid for, in seconds.

    Valid values are between 1 hour and 7 days. The default is 7 days."""

    feature_flags: t.Optional[t.List[str]] = None
    """The set of feature flags the created token will have access to."""

    session_id: t.Optional[str] = None
    """An optional session ID to attach to the token.

    When expiring tokens with "Expire All", you can include the session ID to only expire tokens that were created with that session ID."""



# this file is @generated
import typing as t

from .common import BaseModel
from .event_in import EventIn
from .stream_in import StreamIn


class CreateStreamEventsIn(BaseModel):
    events: t.List[EventIn]

    stream: t.Optional[StreamIn] = None
    """Optionally creates a new Stream alongside the events.

    If the stream id or uid that is used in the path already exists, this argument is ignored."""



# this file is @generated
import typing as t
from datetime import datetime

from .common import BaseModel


class StreamEventTypeOut(BaseModel):
    archived: bool

    created_at: datetime

    deprecated: bool

    description: t.Optional[str] = None

    feature_flags: t.Optional[t.List[str]] = None

    name: str
    """The event type's name"""

    updated_at: datetime



# this file is @generated
import typing as t

from .common import BaseModel


class GoogleCloudStoragePatchConfig(BaseModel):
    bucket: t.Optional[str] = None

    credentials: t.Optional[str] = None



# This file is @generated
import typing as t
from dataclasses import dataclass

from .. import models
from ..models import ListResponseStreamOut, StreamIn, StreamOut, StreamPatch
from .common import ApiBase, BaseOptions, serialize_params


@dataclass
class StreamingStreamListOptions(BaseOptions):
    limit: t.Optional[int] = None
    """Limit the number of returned items"""
    iterator: t.Optional[str] = None
    """The iterator returned from a prior invocation"""
    order: t.Optional[models.Ordering] = None
    """The sorting order of the returned items"""

    def _query_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "limit": self.limit,
                "iterator": self.iterator,
                "order": self.order,
            }
        )


@dataclass
class StreamingStreamCreateOptions(BaseOptions):
    idempotency_key: t.Optional[str] = None

    def _header_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "idempotency-key": self.idempotency_key,
            }
        )


class StreamingStreamAsync(ApiBase):
    async def list(
        self, options: StreamingStreamListOptions = StreamingStreamListOptions()
    ) -> ListResponseStreamOut:
        """List of all the organization's streams."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/stream",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseStreamOut.model_validate(response.json())

    async def create(
        self,
        stream_in: StreamIn,
        options: StreamingStreamCreateOptions = StreamingStreamCreateOptions(),
    ) -> StreamOut:
        """Creates a new stream."""
        response = await self._request_asyncio(
            method="post",
            path="/api/v1/stream",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=stream_in.model_dump_json(exclude_unset=True, by_alias=True),
        )
        return StreamOut.model_validate(response.json())

    async def get(self, stream_id: str) -> StreamOut:
        """Get a stream by id or uid."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/stream/{stream_id}",
            path_params={
                "stream_id": stream_id,
            },
        )
        return StreamOut.model_validate(response.json())

    async def update(self, stream_id: str, stream_in: StreamIn) -> StreamOut:
        """Update a stream."""
        response = await self._request_asyncio(
            method="put",
            path="/api/v1/stream/{stream_id}",
            path_params={
                "stream_id": stream_id,
            },
            json_body=stream_in.model_dump_json(exclude_unset=True, by_alias=True),
        )
        return StreamOut.model_validate(response.json())

    async def delete(self, stream_id: str) -> None:
        """Delete a stream."""
        await self._request_asyncio(
            method="delete",
            path="/api/v1/stream/{stream_id}",
            path_params={
                "stream_id": stream_id,
            },
        )

    async def patch(self, stream_id: str, stream_patch: StreamPatch) -> StreamOut:
        """Partially update a stream."""
        response = await self._request_asyncio(
            method="patch",
            path="/api/v1/stream/{stream_id}",
            path_params={
                "stream_id": stream_id,
            },
            json_body=stream_patch.model_dump_json(exclude_unset=True, by_alias=True),
        )
        return StreamOut.model_validate(response.json())


class StreamingStream(ApiBase):
    def list(
        self, options: StreamingStreamListOptions = StreamingStreamListOptions()
    ) -> ListResponseStreamOut:
        """List of all the organization's streams."""
        response = self._request_sync(
            method="get",
            path="/api/v1/stream",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseStreamOut.model_validate(response.json())

    def create(
        self,
        stream_in: StreamIn,
        options: StreamingStreamCreateOptions = StreamingStreamCreateOptions(),
    ) -> StreamOut:
        """Creates a new stream."""
        response = self._request_sync(
            method="post",
            path="/api/v1/stream",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=stream_in.model_dump_json(exclude_unset=True, by_alias=True),
        )
        return StreamOut.model_validate(response.json())

    def get(self, stream_id: str) -> StreamOut:
        """Get a stream by id or uid."""
        response = self._request_sync(
            method="get",
            path="/api/v1/stream/{stream_id}",
            path_params={
                "stream_id": stream_id,
            },
        )
        return StreamOut.model_validate(response.json())

    def update(self, stream_id: str, stream_in: StreamIn) -> StreamOut:
        """Update a stream."""
        response = self._request_sync(
            method="put",
            path="/api/v1/stream/{stream_id}",
            path_params={
                "stream_id": stream_id,
            },
            json_body=stream_in.model_dump_json(exclude_unset=True, by_alias=True),
        )
        return StreamOut.model_validate(response.json())

    def delete(self, stream_id: str) -> None:
        """Delete a stream."""
        self._request_sync(
            method="delete",
            path="/api/v1/stream/{stream_id}",
            path_params={
                "stream_id": stream_id,
            },
        )

    def patch(self, stream_id: str, stream_patch: StreamPatch) -> StreamOut:
        """Partially update a stream."""
        response = self._request_sync(
            method="patch",
            path="/api/v1/stream/{stream_id}",
            path_params={
                "stream_id": stream_id,
            },
            json_body=stream_patch.model_dump_json(exclude_unset=True, by_alias=True),
        )
        return StreamOut.model_validate(response.json())



import svix
from svix.api import MessageListOptions,IngestSourceIn, CronConfig, ApplicationIn, ApplicationCreateOptions
from svix.api.ingest_source import IngestSource

import httpretty

@httpretty.activate(verbose=True, allow_net_connect=False)
def test_octothorpe_in_query_param():
    svx = svix.Svix("token",svix.SvixOptions(server_url="http://test.example"))
    httpretty.register_uri(
        httpretty.GET,
        "http://test.example/api/v1/app/app_id/msg?tag=test%23test",
        body='{"data":[],"iterator":null,"prevIterator":null,"done":true}'
    )
    svx.message.list("app_id",MessageListOptions(tag="test#test"))

@httpretty.activate(verbose=True, allow_net_connect=False)
def test_struct_enum_with_fields():
    svx = svix.Svix("token", svix.SvixOptions(server_url="http://test.example"))
    ingest_source = IngestSource(svx._client)
    httpretty.register_uri(
        httpretty.POST,
        "http://test.example/ingest/api/v1/source",
        body='{"type":"cron","config":{"content_type":"mendy/tired","payload":"@hello there","schedule":"* * * * *"},"id":"src_2yZwUhtgs5Ai8T9yRQJXA","uid":"unique-identifier","name":"string","ingestUrl":"http://example.com","createdAt":"2019-08-24T14:15:22Z","updatedAt":"2019-08-24T14:15:22Z","metadata":{ }}',
    )
    source_in = IngestSourceIn(
        name="name",
        type="cron",
        config=CronConfig(content_type="asd", payload="asd", schedule="asd"),
    )
    res = ingest_source.create(source_in)
    assert isinstance(res.config, CronConfig)

    assert res.config.content_type == "mendy/tired"
    assert res.config.payload == "@hello there"
    assert res.config.schedule == "* * * * *"


@httpretty.activate(verbose=True, allow_net_connect=False)
def test_struct_enum_without_fields():
    svx = svix.Svix("token", svix.SvixOptions(server_url="http://test.example"))
    ingest_source = IngestSource(svx._client)
    httpretty.register_uri(
        httpretty.POST,
        "http://test.example/ingest/api/v1/source",
        body='{"type":"generic-webhook","id":"src_2yZwUhtgs5Ai8T9yRQJXA","uid":"unique-identifier","name":"string","ingestUrl":"http://example.com","createdAt":"2019-08-24T14:15:22Z","updatedAt":"2019-08-24T14:15:22Z","metadata":{ }}',
    )
    source_in = IngestSourceIn(name="name", type="generic-webhook", config={})

    res = ingest_source.create(source_in)

    assert isinstance(res.config, dict)
    assert res.config == {}

@httpretty.activate(verbose=True, allow_net_connect=False)
def test_idempotency_key_is_sent_for_create_request():
    svx = svix.Svix("token", svix.SvixOptions(server_url="http://test.example"))
    httpretty.register_uri(
        httpretty.POST,
        "http://test.example/api/v1/app",
        body='{"uid":"unique-identifier","name":"My first application","rateLimit":0,"id":"app_1srOrx2ZWZBpBUvZwXKQmoEYga2","createdAt":"2019-08-24T14:15:22Z","updatedAt":"2019-08-24T14:15:22Z","metadata":{"property1":"string","property2":"string"}}'
    )
    svx.application.create(ApplicationIn(name="test app"))

    request = httpretty.latest_requests()[0]
    assert "idempotency-key" in request.headers
    assert request.headers["idempotency-key"].startswith("auto_")


@httpretty.activate(verbose=True, allow_net_connect=False)
def test_client_provided_idempotency_key_is_not_overridden():
    svx = svix.Svix("token", svix.SvixOptions(server_url="http://test.example"))
    httpretty.register_uri(
        httpretty.POST,
        "http://test.example/api/v1/app",
        body='{"uid":"unique-identifier","name":"My first application","rateLimit":0,"id":"app_1srOrx2ZWZBpBUvZwXKQmoEYga2","createdAt":"2019-08-24T14:15:22Z","updatedAt":"2019-08-24T14:15:22Z","metadata":{"property1":"string","property2":"string"}}'
    )

    client_provided_key = "test-key-123"
    svx.application.create(
        ApplicationIn(name="test app"),
        ApplicationCreateOptions(idempotency_key=client_provided_key)
    )

    request = httpretty.latest_requests()[0]
    assert "idempotency-key" in request.headers
    assert request.headers["idempotency-key"] == client_provided_key



@httpretty.activate(verbose=True, allow_net_connect=False)
def test_unknown_keys_are_ignored():
    svx = svix.Svix("token", svix.SvixOptions(server_url="http://test.example"))
    httpretty.register_uri(
        httpretty.GET,
        "http://test.example/api/v1/app",
        body='{"data":[],"done":true,"iterator":null,"prevIterator":null,"extra-key":"ignored"}'
    )


    svx.application.list()



# This file is @generated
import typing as t
from dataclasses import dataclass

from .. import models
from ..models import (
    ConnectorIn,
    ConnectorOut,
    ConnectorPatch,
    ConnectorUpdate,
    ListResponseConnectorOut,
)
from .common import ApiBase, BaseOptions, serialize_params


@dataclass
class ConnectorListOptions(BaseOptions):
    limit: t.Optional[int] = None
    """Limit the number of returned items"""
    iterator: t.Optional[str] = None
    """The iterator returned from a prior invocation"""
    order: t.Optional[models.Ordering] = None
    """The sorting order of the returned items"""

    def _query_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "limit": self.limit,
                "iterator": self.iterator,
                "order": self.order,
            }
        )


@dataclass
class ConnectorCreateOptions(BaseOptions):
    idempotency_key: t.Optional[str] = None

    def _header_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "idempotency-key": self.idempotency_key,
            }
        )


class ConnectorAsync(ApiBase):
    async def list(
        self, options: ConnectorListOptions = ConnectorListOptions()
    ) -> ListResponseConnectorOut:
        """List all connectors for an application."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/connector",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseConnectorOut.model_validate(response.json())

    async def create(
        self,
        connector_in: ConnectorIn,
        options: ConnectorCreateOptions = ConnectorCreateOptions(),
    ) -> ConnectorOut:
        """Create a new connector."""
        response = await self._request_asyncio(
            method="post",
            path="/api/v1/connector",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=connector_in.model_dump_json(exclude_unset=True, by_alias=True),
        )
        return ConnectorOut.model_validate(response.json())

    async def get(self, connector_id: str) -> ConnectorOut:
        """Get a connector."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/connector/{connector_id}",
            path_params={
                "connector_id": connector_id,
            },
        )
        return ConnectorOut.model_validate(response.json())

    async def update(
        self, connector_id: str, connector_update: ConnectorUpdate
    ) -> ConnectorOut:
        """Update a connector."""
        response = await self._request_asyncio(
            method="put",
            path="/api/v1/connector/{connector_id}",
            path_params={
                "connector_id": connector_id,
            },
            json_body=connector_update.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return ConnectorOut.model_validate(response.json())

    async def delete(self, connector_id: str) -> None:
        """Delete a connector."""
        await self._request_asyncio(
            method="delete",
            path="/api/v1/connector/{connector_id}",
            path_params={
                "connector_id": connector_id,
            },
        )

    async def patch(
        self, connector_id: str, connector_patch: ConnectorPatch
    ) -> ConnectorOut:
        """Partially update a connector."""
        response = await self._request_asyncio(
            method="patch",
            path="/api/v1/connector/{connector_id}",
            path_params={
                "connector_id": connector_id,
            },
            json_body=connector_patch.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return ConnectorOut.model_validate(response.json())


class Connector(ApiBase):
    def list(
        self, options: ConnectorListOptions = ConnectorListOptions()
    ) -> ListResponseConnectorOut:
        """List all connectors for an application."""
        response = self._request_sync(
            method="get",
            path="/api/v1/connector",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseConnectorOut.model_validate(response.json())

    def create(
        self,
        connector_in: ConnectorIn,
        options: ConnectorCreateOptions = ConnectorCreateOptions(),
    ) -> ConnectorOut:
        """Create a new connector."""
        response = self._request_sync(
            method="post",
            path="/api/v1/connector",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=connector_in.model_dump_json(exclude_unset=True, by_alias=True),
        )
        return ConnectorOut.model_validate(response.json())

    def get(self, connector_id: str) -> ConnectorOut:
        """Get a connector."""
        response = self._request_sync(
            method="get",
            path="/api/v1/connector/{connector_id}",
            path_params={
                "connector_id": connector_id,
            },
        )
        return ConnectorOut.model_validate(response.json())

    def update(
        self, connector_id: str, connector_update: ConnectorUpdate
    ) -> ConnectorOut:
        """Update a connector."""
        response = self._request_sync(
            method="put",
            path="/api/v1/connector/{connector_id}",
            path_params={
                "connector_id": connector_id,
            },
            json_body=connector_update.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return ConnectorOut.model_validate(response.json())

    def delete(self, connector_id: str) -> None:
        """Delete a connector."""
        self._request_sync(
            method="delete",
            path="/api/v1/connector/{connector_id}",
            path_params={
                "connector_id": connector_id,
            },
        )

    def patch(self, connector_id: str, connector_patch: ConnectorPatch) -> ConnectorOut:
        """Partially update a connector."""
        response = self._request_sync(
            method="patch",
            path="/api/v1/connector/{connector_id}",
            path_params={
                "connector_id": connector_id,
            },
            json_body=connector_patch.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return ConnectorOut.model_validate(response.json())



# this file is @generated
import typing as t

from .app_portal_capability import AppPortalCapability
from .application_in import ApplicationIn
from .common import BaseModel


class AppPortalAccessIn(BaseModel):
    application: t.Optional[ApplicationIn] = None
    """Optionally creates a new application while generating the access link.

    If the application id or uid that is used in the path already exists, this argument is ignored."""

    capabilities: t.Optional[t.List[AppPortalCapability]] = None
    """Custom capabilities attached to the token, You can combine as many capabilities as necessary.

    The `ViewBase` capability is always required

    - `ViewBase`: Basic read only permissions, does not allow the user to see the endpoint secret.

    - `ViewEndpointSecret`: Allows user to view the endpoint secret.

    - `ManageEndpointSecret`: Allows user to rotate and view the endpoint secret.

    - `ManageTransformations`: Allows user to modify the endpoint transformations.

    - `CreateAttempts`: Allows user to replay missing messages and send example messages.

    - `ManageEndpoint`: Allows user to read/modify any field or configuration of an endpoint (including secrets)"""

    expiry: t.Optional[int] = None
    """How long the token will be valid for, in seconds.

    Valid values are between 1 hour and 7 days. The default is 7 days."""

    feature_flags: t.Optional[t.List[str]] = None
    """The set of feature flags the created token will have access to."""

    read_only: t.Optional[bool] = None
    """Whether the app portal should be in read-only mode."""

    session_id: t.Optional[str] = None
    """An optional session ID to attach to the token.

    When expiring tokens with "Expire All", you can include the session ID to only expire tokens that were created with that session ID."""



# this file is @generated
import typing as t
from datetime import datetime

from .common import BaseModel
from .message_status import MessageStatus
from .message_status_text import MessageStatusText


class EndpointMessageOut(BaseModel):
    """A model containing information on a given message plus additional fields on the last attempt for that message."""

    channels: t.Optional[t.List[str]] = None
    """List of free-form identifiers that endpoints can filter by"""

    deliver_at: t.Optional[datetime] = None

    event_id: t.Optional[str] = None
    """Optional unique identifier for the message"""

    event_type: str
    """The event type's name"""

    id: str
    """The Message's ID."""

    next_attempt: t.Optional[datetime] = None

    payload: t.Dict[str, t.Any]

    status: MessageStatus

    status_text: MessageStatusText

    tags: t.Optional[t.List[str]] = None

    timestamp: datetime



# this file is @generated
import typing as t

from .common import BaseModel


class StreamPatch(BaseModel):
    description: t.Optional[str] = None
    """The Stream's description."""

    metadata: t.Optional[t.Dict[str, str]] = None

    uid: t.Optional[str] = None
    """An optional unique identifier for the stream."""



# this file is @generated
from enum import Enum


class MessageStatusText(str, Enum):
    SUCCESS = "success"
    PENDING = "pending"
    FAIL = "fail"
    SENDING = "sending"

    def __str__(self) -> str:
        return str(self.value)



# This file is @generated
import typing as t
from dataclasses import dataclass

from .. import models
from ..models import (
    IngestEndpointHeadersIn,
    IngestEndpointHeadersOut,
    IngestEndpointIn,
    IngestEndpointOut,
    IngestEndpointSecretIn,
    IngestEndpointSecretOut,
    IngestEndpointTransformationOut,
    IngestEndpointTransformationPatch,
    IngestEndpointUpdate,
    ListResponseIngestEndpointOut,
)
from .common import ApiBase, BaseOptions, serialize_params


@dataclass
class IngestEndpointListOptions(BaseOptions):
    limit: t.Optional[int] = None
    """Limit the number of returned items"""
    iterator: t.Optional[str] = None
    """The iterator returned from a prior invocation"""
    order: t.Optional[models.Ordering] = None
    """The sorting order of the returned items"""

    def _query_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "limit": self.limit,
                "iterator": self.iterator,
                "order": self.order,
            }
        )


@dataclass
class IngestEndpointCreateOptions(BaseOptions):
    idempotency_key: t.Optional[str] = None

    def _header_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "idempotency-key": self.idempotency_key,
            }
        )


@dataclass
class IngestEndpointRotateSecretOptions(BaseOptions):
    idempotency_key: t.Optional[str] = None

    def _header_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "idempotency-key": self.idempotency_key,
            }
        )


class IngestEndpointAsync(ApiBase):
    async def list(
        self,
        source_id: str,
        options: IngestEndpointListOptions = IngestEndpointListOptions(),
    ) -> ListResponseIngestEndpointOut:
        """List ingest endpoints."""
        response = await self._request_asyncio(
            method="get",
            path="/ingest/api/v1/source/{source_id}/endpoint",
            path_params={
                "source_id": source_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseIngestEndpointOut.model_validate(response.json())

    async def create(
        self,
        source_id: str,
        ingest_endpoint_in: IngestEndpointIn,
        options: IngestEndpointCreateOptions = IngestEndpointCreateOptions(),
    ) -> IngestEndpointOut:
        """Create an ingest endpoint."""
        response = await self._request_asyncio(
            method="post",
            path="/ingest/api/v1/source/{source_id}/endpoint",
            path_params={
                "source_id": source_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=ingest_endpoint_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return IngestEndpointOut.model_validate(response.json())

    async def get(self, source_id: str, endpoint_id: str) -> IngestEndpointOut:
        """Get an ingest endpoint."""
        response = await self._request_asyncio(
            method="get",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
        )
        return IngestEndpointOut.model_validate(response.json())

    async def update(
        self,
        source_id: str,
        endpoint_id: str,
        ingest_endpoint_update: IngestEndpointUpdate,
    ) -> IngestEndpointOut:
        """Update an ingest endpoint."""
        response = await self._request_asyncio(
            method="put",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
            json_body=ingest_endpoint_update.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return IngestEndpointOut.model_validate(response.json())

    async def delete(self, source_id: str, endpoint_id: str) -> None:
        """Delete an ingest endpoint."""
        await self._request_asyncio(
            method="delete",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
        )

    async def get_headers(
        self, source_id: str, endpoint_id: str
    ) -> IngestEndpointHeadersOut:
        """Get the additional headers to be sent with the ingest."""
        response = await self._request_asyncio(
            method="get",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/headers",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
        )
        return IngestEndpointHeadersOut.model_validate(response.json())

    async def update_headers(
        self,
        source_id: str,
        endpoint_id: str,
        ingest_endpoint_headers_in: IngestEndpointHeadersIn,
    ) -> None:
        """Set the additional headers to be sent to the endpoint."""
        await self._request_asyncio(
            method="put",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/headers",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
            json_body=ingest_endpoint_headers_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )

    async def get_secret(
        self, source_id: str, endpoint_id: str
    ) -> IngestEndpointSecretOut:
        """Get an ingest endpoint's signing secret.

        This is used to verify the authenticity of the webhook.
        For more information please refer to [the consuming webhooks docs](https://docs.svix.com/consuming-webhooks/)."""
        response = await self._request_asyncio(
            method="get",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/secret",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
        )
        return IngestEndpointSecretOut.model_validate(response.json())

    async def rotate_secret(
        self,
        source_id: str,
        endpoint_id: str,
        ingest_endpoint_secret_in: IngestEndpointSecretIn,
        options: IngestEndpointRotateSecretOptions = IngestEndpointRotateSecretOptions(),
    ) -> None:
        """Rotates an ingest endpoint's signing secret.

        The previous secret will remain valid for the next 24 hours."""
        await self._request_asyncio(
            method="post",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/secret/rotate",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=ingest_endpoint_secret_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )

    async def get_transformation(
        self, source_id: str, endpoint_id: str
    ) -> IngestEndpointTransformationOut:
        """Get the transformation code associated with this ingest endpoint."""
        response = await self._request_asyncio(
            method="get",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/transformation",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
        )
        return IngestEndpointTransformationOut.model_validate(response.json())

    async def set_transformation(
        self,
        source_id: str,
        endpoint_id: str,
        ingest_endpoint_transformation_patch: IngestEndpointTransformationPatch,
    ) -> None:
        """Set or unset the transformation code associated with this ingest endpoint."""
        await self._request_asyncio(
            method="patch",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/transformation",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
            json_body=ingest_endpoint_transformation_patch.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )


class IngestEndpoint(ApiBase):
    def list(
        self,
        source_id: str,
        options: IngestEndpointListOptions = IngestEndpointListOptions(),
    ) -> ListResponseIngestEndpointOut:
        """List ingest endpoints."""
        response = self._request_sync(
            method="get",
            path="/ingest/api/v1/source/{source_id}/endpoint",
            path_params={
                "source_id": source_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseIngestEndpointOut.model_validate(response.json())

    def create(
        self,
        source_id: str,
        ingest_endpoint_in: IngestEndpointIn,
        options: IngestEndpointCreateOptions = IngestEndpointCreateOptions(),
    ) -> IngestEndpointOut:
        """Create an ingest endpoint."""
        response = self._request_sync(
            method="post",
            path="/ingest/api/v1/source/{source_id}/endpoint",
            path_params={
                "source_id": source_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=ingest_endpoint_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return IngestEndpointOut.model_validate(response.json())

    def get(self, source_id: str, endpoint_id: str) -> IngestEndpointOut:
        """Get an ingest endpoint."""
        response = self._request_sync(
            method="get",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
        )
        return IngestEndpointOut.model_validate(response.json())

    def update(
        self,
        source_id: str,
        endpoint_id: str,
        ingest_endpoint_update: IngestEndpointUpdate,
    ) -> IngestEndpointOut:
        """Update an ingest endpoint."""
        response = self._request_sync(
            method="put",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
            json_body=ingest_endpoint_update.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return IngestEndpointOut.model_validate(response.json())

    def delete(self, source_id: str, endpoint_id: str) -> None:
        """Delete an ingest endpoint."""
        self._request_sync(
            method="delete",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
        )

    def get_headers(self, source_id: str, endpoint_id: str) -> IngestEndpointHeadersOut:
        """Get the additional headers to be sent with the ingest."""
        response = self._request_sync(
            method="get",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/headers",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
        )
        return IngestEndpointHeadersOut.model_validate(response.json())

    def update_headers(
        self,
        source_id: str,
        endpoint_id: str,
        ingest_endpoint_headers_in: IngestEndpointHeadersIn,
    ) -> None:
        """Set the additional headers to be sent to the endpoint."""
        self._request_sync(
            method="put",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/headers",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
            json_body=ingest_endpoint_headers_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )

    def get_secret(self, source_id: str, endpoint_id: str) -> IngestEndpointSecretOut:
        """Get an ingest endpoint's signing secret.

        This is used to verify the authenticity of the webhook.
        For more information please refer to [the consuming webhooks docs](https://docs.svix.com/consuming-webhooks/)."""
        response = self._request_sync(
            method="get",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/secret",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
        )
        return IngestEndpointSecretOut.model_validate(response.json())

    def rotate_secret(
        self,
        source_id: str,
        endpoint_id: str,
        ingest_endpoint_secret_in: IngestEndpointSecretIn,
        options: IngestEndpointRotateSecretOptions = IngestEndpointRotateSecretOptions(),
    ) -> None:
        """Rotates an ingest endpoint's signing secret.

        The previous secret will remain valid for the next 24 hours."""
        self._request_sync(
            method="post",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/secret/rotate",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=ingest_endpoint_secret_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )

    def get_transformation(
        self, source_id: str, endpoint_id: str
    ) -> IngestEndpointTransformationOut:
        """Get the transformation code associated with this ingest endpoint."""
        response = self._request_sync(
            method="get",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/transformation",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
        )
        return IngestEndpointTransformationOut.model_validate(response.json())

    def set_transformation(
        self,
        source_id: str,
        endpoint_id: str,
        ingest_endpoint_transformation_patch: IngestEndpointTransformationPatch,
    ) -> None:
        """Set or unset the transformation code associated with this ingest endpoint."""
        self._request_sync(
            method="patch",
            path="/ingest/api/v1/source/{source_id}/endpoint/{endpoint_id}/transformation",
            path_params={
                "source_id": source_id,
                "endpoint_id": endpoint_id,
            },
            json_body=ingest_endpoint_transformation_patch.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )



# this file is @generated
import typing as t

from .common import BaseModel


class AmazonS3PatchConfig(BaseModel):
    access_key_id: t.Optional[str] = None

    bucket: t.Optional[str] = None

    region: t.Optional[str] = None

    secret_access_key: t.Optional[str] = None



# this file is @generated

from .common import BaseModel


class GoogleCloudStorageConfig(BaseModel):
    """Configuration for a Google Cloud Storage sink.

    Write stream events into the named bucket using the supplied Google Cloud credentials."""

    bucket: str

    credentials: str
    """Google Cloud Credentials JSON Object as a string."""



# this file is @generated
from datetime import datetime

from .common import BaseModel


class EventOut(BaseModel):
    event_type: str
    """The event type's name"""

    payload: str

    timestamp: datetime



# this file is @generated
import typing as t
from datetime import datetime

from pydantic import ModelWrapValidatorHandler, model_validator
from typing_extensions import Self

from .azure_blob_storage_config import AzureBlobStorageConfig
from .common import BaseModel
from .google_cloud_storage_config import GoogleCloudStorageConfig
from .s3_config import S3Config
from .sink_http_config import SinkHttpConfig
from .sink_otel_v1_config import SinkOtelV1Config
from .sink_status import SinkStatus


class StreamSinkOut(BaseModel):
    batch_size: int

    created_at: datetime

    current_iterator: str

    event_types: t.Optional[t.List[str]] = None

    failure_reason: t.Optional[str] = None

    id: str
    """The sink's ID."""

    max_wait_secs: int

    metadata: t.Dict[str, str]

    next_retry_at: t.Optional[datetime] = None

    status: SinkStatus

    uid: t.Optional[str] = None
    """The sink's UID."""

    updated_at: datetime

    type: t.Union[
        t.Literal["poller"],
        t.Literal["azureBlobStorage"],
        t.Literal["otelTracing"],
        t.Literal["http"],
        t.Literal["amazonS3"],
        t.Literal["googleCloudStorage"],
    ]
    config: t.Union[
        t.Dict[str, t.Any],
        AzureBlobStorageConfig,
        SinkOtelV1Config,
        SinkHttpConfig,
        S3Config,
        GoogleCloudStorageConfig,
    ]

    @model_validator(mode="wrap")
    @classmethod
    def validate_model(
        cls, data: t.Any, handler: ModelWrapValidatorHandler[Self]
    ) -> Self:
        if "config" not in data:
            data["config"] = {}
        output = handler(data)
        if output.type == "poller":
            output.config = data.get("config", {})
        elif output.type == "azureBlobStorage":
            output.config = AzureBlobStorageConfig.model_validate(
                data.get("config", {})
            )
        elif output.type == "otelTracing":
            output.config = SinkOtelV1Config.model_validate(data.get("config", {}))
        elif output.type == "http":
            output.config = SinkHttpConfig.model_validate(data.get("config", {}))
        elif output.type == "amazonS3":
            output.config = S3Config.model_validate(data.get("config", {}))
        elif output.type == "googleCloudStorage":
            output.config = GoogleCloudStorageConfig.model_validate(
                data.get("config", {})
            )
        else:
            raise ValueError(f"Unexpected type `{output.type}`")
        return output



# this file is @generated
import typing as t

from .common import BaseModel


class StreamEventTypeIn(BaseModel):
    archived: t.Optional[bool] = None

    deprecated: t.Optional[bool] = None

    description: t.Optional[str] = None

    feature_flags: t.Optional[t.List[str]] = None

    name: str
    """The event type's name"""



# this file is @generated
import typing as t

from .common import BaseModel
from .stream_sink_out import StreamSinkOut


class ListResponseStreamSinkOut(BaseModel):
    data: t.List[StreamSinkOut]

    done: bool

    iterator: t.Optional[str]

    prev_iterator: t.Optional[str] = None
